@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -33,23 +33,20 @@
 """
 
 import uuid
+
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
 from tvb.adapters.datatypes.db.patterns import StimuliRegionIndex, StimuliSurfaceIndex
 from tvb.adapters.datatypes.db.surface import SurfaceIndex
-from tvb.adapters.simulator.equation_forms import get_form_for_equation
-from tvb.adapters.simulator.subforms_mapping import DOUBLE_GAUSSIAN_EQUATION, SIGMOID_EQUATION
-from tvb.adapters.simulator.subforms_mapping import get_ui_name_to_equation_dict, GAUSSIAN_EQUATION
-from tvb.basic.neotraits.api import Attr
+from tvb.adapters.simulator.equation_forms import get_form_for_equation, SpatialEquationsEnum, TemporalEquationsEnum
+from tvb.basic.neotraits.api import Attr, EnumAttr
 from tvb.core.adapters.abcadapter import ABCAdapterForm, AdapterLaunchModeEnum, ABCAdapter
 from tvb.core.entities.filters.chain import FilterChain
-from tvb.core.entities.load import load_entity_by_gid
 from tvb.core.neocom import h5
 from tvb.core.neotraits.forms import FormField, TraitDataTypeSelectField, SelectField, StrField
 from tvb.core.neotraits.view_model import ViewModel, DataTypeGidAttr, Str
 from tvb.datatypes.connectivity import Connectivity
-from tvb.datatypes.equations import Sigmoid, PulseTrain, TemporalApplicableEquation, FiniteSupportEquation
 from tvb.datatypes.patterns import StimuliSurface, StimuliRegion
-from tvb.datatypes.surfaces import CorticalSurface, CORTICAL
+from tvb.datatypes.surfaces import CorticalSurface, SurfaceTypesEnum
 
 
 class StimulusSurfaceSelectorForm(ABCAdapterForm):
@@ -65,8 +62,10 @@ class StimulusSurfaceSelectorForm(ABCAdapterForm):
 
 
 class SurfaceStimulusCreatorModel(ViewModel, StimuliSurface):
-    spatial = Attr(field_type=FiniteSupportEquation, label="Spatial Equation", default=Sigmoid())
-    temporal = Attr(field_type=TemporalApplicableEquation, label="Temporal Equation", default=PulseTrain())
+    spatial = EnumAttr(field_type=SpatialEquationsEnum, label="Spatial Equation",
+                       default=SpatialEquationsEnum.SIGMOID.instance)
+    temporal = EnumAttr(field_type=TemporalEquationsEnum, label="Temporal Equation",
+                        default=TemporalEquationsEnum.PULSETRAIN.instance)
 
     surface = DataTypeGidAttr(
         linked_datatype=CorticalSurface,
@@ -82,23 +81,20 @@ class SurfaceStimulusCreatorModel(ViewModel, StimuliSurface):
 class SurfaceStimulusCreatorForm(ABCAdapterForm):
     NAME_SPATIAL_PARAMS_DIV = 'spatial_params'
     NAME_TEMPORAL_PARAMS_DIV = 'temporal_params'
-    default_spatial = Sigmoid
-    default_temporal = PulseTrain
-    choices_temporal = get_ui_name_to_equation_dict()
-    choices_spatial = {GAUSSIAN_EQUATION: choices_temporal.get(GAUSSIAN_EQUATION),
-                       DOUBLE_GAUSSIAN_EQUATION: choices_temporal.get(DOUBLE_GAUSSIAN_EQUATION),
-                       SIGMOID_EQUATION: choices_temporal.get(SIGMOID_EQUATION)}
+    default_spatial = SpatialEquationsEnum.SIGMOID
+    default_temporal = TemporalEquationsEnum.PULSETRAIN
 
     def __init__(self):
         super(SurfaceStimulusCreatorForm, self).__init__()
 
         self.surface = TraitDataTypeSelectField(SurfaceStimulusCreatorModel.surface, name='surface',
                                                 conditions=self.get_filters())
-        self.spatial = SelectField(SurfaceStimulusCreatorModel.spatial, name='spatial', choices=self.choices_spatial,
-                                   subform=get_form_for_equation(self.default_spatial))
+        self.spatial = SelectField(SurfaceStimulusCreatorModel.spatial, name='spatial',
+                                   subform=get_form_for_equation(self.default_spatial.value))
         self.temporal = SelectField(SurfaceStimulusCreatorModel.temporal, name='temporal',
-                                    choices=self.choices_temporal,
-                                    subform=get_form_for_equation(self.default_temporal))
+                                    subform=get_form_for_equation(self.default_temporal.value))
+
+        del self.spatial.choices[-1]
 
     @staticmethod
     def get_view_model():
@@ -115,7 +111,7 @@ class SurfaceStimulusCreatorForm(ABCAdapterForm):
     @staticmethod
     def get_filters():
         return FilterChain(fields=[FilterChain.datatype + '.surface_type'], operations=["=="],
-                           values=[CORTICAL])
+                           values=[SurfaceTypesEnum.CORTICAL_SURFACE.value])
 
     def fill_from_trait(self, trait):
         self.surface.data = trait.surface.hex
@@ -124,7 +120,8 @@ class SurfaceStimulusCreatorForm(ABCAdapterForm):
         self.temporal.subform_field = FormField(get_form_for_equation(type(trait.temporal)),
                                                 self.NAME_TEMPORAL_PARAMS_DIV)
         self.temporal.subform_field.form.fill_from_trait(trait.temporal)
-        self.spatial.subform_field = FormField(get_form_for_equation(type(trait.spatial)), self.NAME_SPATIAL_PARAMS_DIV)
+        self.spatial.subform_field = FormField(get_form_for_equation(type(trait.spatial)),
+                                               self.NAME_SPATIAL_PARAMS_DIV)
         self.spatial.subform_field.form.fill_from_trait(trait.spatial)
 
     def get_rendering_dict(self):
@@ -152,8 +149,7 @@ class SurfaceStimulusCreator(ABCAdapter):
         """
         return [StimuliSurfaceIndex]
 
-    @staticmethod
-    def prepare_stimuli_surface_from_view_model(view_model, load_full_surface=False):
+    def prepare_stimuli_surface_from_view_model(self, view_model, load_full_surface=False):
         # type: (SurfaceStimulusCreatorModel, bool) -> StimuliSurface
         stimuli_surface = StimuliSurface()
 
@@ -161,16 +157,14 @@ class SurfaceStimulusCreator(ABCAdapter):
         stimuli_surface.spatial = view_model.spatial
         stimuli_surface.temporal = view_model.temporal
 
-        surface_index = load_entity_by_gid(view_model.surface)
         if load_full_surface:
-            stimuli_surface.surface = h5.load_from_index(surface_index)
+            stimuli_surface.surface = self.load_traited_by_gid(view_model.surface)
         else:
             stimuli_surface.surface = CorticalSurface()
             stimuli_surface.gid = view_model.surface
-            surface_h5 = h5.h5_file_for_index(surface_index)
             # We need to load surface triangles on stimuli because focal_points_surface property needs to acces them
-            stimuli_surface.surface.triangles = surface_h5.triangles.load()
-            surface_h5.close()
+            with h5.h5_file_for_gid(view_model.surface) as surface_h5:
+                stimuli_surface.surface.triangles = surface_h5.triangles.load()
 
         return stimuli_surface
 
@@ -181,7 +175,7 @@ class SurfaceStimulusCreator(ABCAdapter):
         """
         self.generic_attributes.user_tag_1 = view_model.display_name
         stimuli_surface = self.prepare_stimuli_surface_from_view_model(view_model, view_model.surface)
-        stimuli_surface_index = h5.store_complete(stimuli_surface, self.storage_path)
+        stimuli_surface_index = self.store_complete(stimuli_surface)
         return stimuli_surface_index
 
     def get_required_memory_size(self, view_model):
@@ -212,7 +206,8 @@ class StimulusRegionSelectorForm(ABCAdapterForm):
 
 
 class RegionStimulusCreatorModel(ViewModel, StimuliRegion):
-    temporal = Attr(field_type=TemporalApplicableEquation, label="Temporal Equation", default=PulseTrain())
+    temporal = EnumAttr(field_type=TemporalEquationsEnum, label="Temporal Equation",
+                        default=TemporalEquationsEnum.PULSETRAIN.instance)
 
     connectivity = DataTypeGidAttr(
         field_type=uuid.UUID,
@@ -228,14 +223,13 @@ class RegionStimulusCreatorModel(ViewModel, StimuliRegion):
 
 class RegionStimulusCreatorForm(ABCAdapterForm):
     NAME_TEMPORAL_PARAMS_DIV = 'temporal_params'
-    default_temporal = PulseTrain
-    choices = get_ui_name_to_equation_dict()
+    default_temporal = TemporalEquationsEnum.PULSETRAIN
 
     def __init__(self):
         super(RegionStimulusCreatorForm, self).__init__()
         self.connectivity = TraitDataTypeSelectField(RegionStimulusCreatorModel.connectivity, name='connectivity')
-        self.temporal = SelectField(RegionStimulusCreatorModel.temporal, name='temporal', choices=self.choices,
-                                    subform=get_form_for_equation(self.default_temporal))
+        self.temporal = SelectField(RegionStimulusCreatorModel.temporal, name='temporal',
+                                    subform=get_form_for_equation(self.default_temporal.value))
 
     @staticmethod
     def get_view_model():
@@ -293,7 +287,7 @@ class RegionStimulusCreator(ABCAdapter):
         stimuli_region.temporal = view_model.temporal
         self.generic_attributes.user_tag_1 = view_model.display_name
 
-        stimuli_region_idx = h5.store_complete(stimuli_region, self.storage_path)
+        stimuli_region_idx = self.store_complete(stimuli_region)
         return stimuli_region_idx
 
     def get_required_disk_size(self, view_model):
