@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -36,21 +36,18 @@ Exceptions for services layer of the application.
 from tvb.basic.exceptions import TVBException
 
 
-
 class ServicesBaseException(TVBException):
     """
     Base Exception class for Services layer in the application.
     """
 
 
-
 class StructureException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem related to Structure Storage.
     """
 
 
-
 class OperationException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem related to Launching 
@@ -58,7 +55,6 @@ class OperationException(ServicesBaseException):
     """
 
 
-
 class UsernameException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem related to creating
@@ -66,24 +62,6 @@ class UsernameException(ServicesBaseException):
     """
 
 
-
-class WorkflowException(ServicesBaseException):
-    """
-    Exception to be thrown in case of a problem related to creating
-    or managing a workflow.
-    """
-
-
-
-class WorkflowInterStepsException(WorkflowException):
-    """
-    Exception to be thrown in case of a problem happened between steps of a workflow.
-    Status ERROR needs to be reported at a top level (e.g. Burst) as workflow 
-    steps individually can not be made responsible.
-    """
-
-
-
 class ProjectServiceException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem in the projectservice
@@ -91,13 +69,23 @@ class ProjectServiceException(ServicesBaseException):
     """
 
 
-
 class ImportException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem at project import.
     """
 
 
+class MissingReferenceException(ImportException):
+    """
+    Exception to be thrown in case there are missing references when importing a H5 file.
+    """
+
+
+class DatatypeGroupImportException(ImportException):
+    """
+    Exception to be thrown in case there are issues when importing a datatype group.
+    """
+
 
 class BurstServiceException(ServicesBaseException):
     """
@@ -105,25 +93,14 @@ class BurstServiceException(ServicesBaseException):
     """
 
 
-
-class InvalidPortletConfiguration(ServicesBaseException):
-    """
-    Exception thrown in cases related to wrong portlet configurations.
-    """
-
-
-
 class InvalidSettingsException(ServicesBaseException):
     """
     Exception to be thrown in case of a problem at project import.
     """
 
 
-
 class RemoveDataTypeException(ServicesBaseException):
     """
     Exception to be thrown in case some one tries to remove an
     entity that is used by other entities.
     """
-
-
