@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -36,28 +36,33 @@ Service Layer for the Project entity.
 """
 
 import formencode
+import os
+import uuid
+
 from tvb.basic.logger.builder import get_logger
+from tvb.config import DATATYPE_MEASURE_INDEX_MODULE, DATATYPE_MEASURE_INDEX_CLASS
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.adapters.inputs_processor import review_operation_inputs_from_adapter
-from tvb.core.entities.load import load_entity_by_gid
+from tvb.core.entities.file.simulator.burst_configuration_h5 import BurstConfigurationH5
+from tvb.core.entities.load import get_class_by_name, load_entity_by_gid
 from tvb.core.entities.model.model_burst import BurstConfiguration
 from tvb.core.entities.model.model_datatype import Links, DataType, DataTypeGroup
 from tvb.core.entities.model.model_operation import Operation, OperationGroup
 from tvb.core.entities.model.model_project import Project
 from tvb.core.entities.storage import dao, transactional
 from tvb.core.entities.transient.context_overlay import CommonDetails, DataTypeOverlayDetails, OperationOverlayDetails
-from tvb.core.entities.filters.factory import StaticFiltersFactory
 from tvb.core.entities.transient.structure_entities import StructureNode, DataTypeMetaData
-from tvb.core.entities.file.files_helper import FilesHelper
-from tvb.core.entities.file.exceptions import FileStructureException
 from tvb.core.neocom import h5
 from tvb.core.neotraits.h5 import H5File, ViewModelH5
 from tvb.core.removers_factory import get_remover
 from tvb.core.services.algorithm_service import AlgorithmService
-from tvb.core.services.exceptions import StructureException, ProjectServiceException
 from tvb.core.services.exceptions import RemoveDataTypeException
+from tvb.core.services.exceptions import StructureException, ProjectServiceException
 from tvb.core.services.user_service import UserService, MEMBERS_PAGE_SIZE
-from tvb.core.utils import string2date, date2string, format_timedelta, format_bytes_human
+from tvb.core.utils import format_timedelta, format_bytes_human
+from tvb.core.utils import string2date, date2string
+from tvb.storage.h5.file.exceptions import FileStructureException
+from tvb.storage.storage_interface import StorageInterface
 
 
 def initialize_storage():
@@ -65,8 +70,7 @@ def initialize_storage():
     Create Projects storage root folder in case it does not exist.
     """
     try:
-        helper = FilesHelper()
-        helper.check_created()
+        StorageInterface().check_created()
     except FileStructureException:
         # Do nothing, because we do not have any UI to display exception
         logger = get_logger("tvb.core.services.initialize_storage")
@@ -87,7 +91,7 @@ class ProjectService:
 
     def __init__(self):
         self.logger = get_logger(__name__)
-        self.structure_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
 
     def store_project(self, current_user, is_create, selected_id, **data):
         """
@@ -106,7 +110,7 @@ class ProjectService:
             raise ProjectServiceException("A project can not be renamed while operations are still running!")
         if is_create:
             current_proj = Project(new_name, current_user.id, data["description"])
-            self.structure_helper.get_project_folder(current_proj)
+            self.storage_interface.get_project_folder(current_proj.name)
         else:
             try:
                 current_proj = dao.get_project_by_id(selected_id)
@@ -114,12 +118,13 @@ class ProjectService:
                 self.logger.exception("An error has occurred!")
                 raise ProjectServiceException(str(excep))
             if current_proj.name != new_name:
-                self.structure_helper.rename_project_structure(current_proj.name, new_name)
+                self.storage_interface.rename_project(current_proj.name, new_name)
             current_proj.name = new_name
             current_proj.description = data["description"]
         # Commit to make sure we have a valid ID
         current_proj.refresh_update_date()
-        self.structure_helper.write_project_metadata(current_proj)
+        _, metadata_proj = current_proj.to_dict()
+        self.storage_interface.write_project_metadata(metadata_proj)
         current_proj = dao.store_entity(current_proj)
 
         # Retrieve, to initialize lazy attributes
@@ -197,17 +202,23 @@ class ProjectService:
                 result["burst_name"] = burst.name if burst else '-'
                 result["count"] = one_op[2]
                 result["gid"] = one_op[13]
-                if one_op[3] is not None and one_op[3]:
+                operation_group_id = one_op[3]
+                if operation_group_id is not None and operation_group_id:
                     try:
-                        operation_group = dao.get_generic_entity(OperationGroup, one_op[3])[0]
+                        operation_group = dao.get_generic_entity(OperationGroup, operation_group_id)[0]
                         result["group"] = operation_group.name
                         result["group"] = result["group"].replace("_", " ")
                         result["operation_group_id"] = operation_group.id
-                        datatype_group = dao.get_datatypegroup_by_op_group_id(one_op[3])
-                        result["datatype_group_gid"] = datatype_group.gid
+                        datatype_group = dao.get_datatypegroup_by_op_group_id(operation_group_id)
+                        result["datatype_group_gid"] = datatype_group.gid if datatype_group is not None else None
                         result["gid"] = operation_group.gid
                         # Filter only viewers for current DataTypeGroup entity:
-                        result["view_groups"] = AlgorithmService().get_visualizers_for_group(datatype_group.gid)
+
+                        if datatype_group is None:
+                            view_groups = None
+                        else:
+                            view_groups = AlgorithmService().get_visualizers_for_group(datatype_group.gid)
+                        result["view_groups"] = view_groups
                     except Exception:
                         self.logger.exception("We will ignore group on entity:" + str(one_op))
                         result["datatype_group_gid"] = None
@@ -236,15 +247,7 @@ class ProjectService:
                 result["visible"] = True if one_op[11] > 0 else False
                 result['operation_tag'] = one_op[12]
                 if not result['group']:
-                    datatype_results = dao.get_results_for_operation(result['id'])
-                    result['results'] = []
-                    for dt in datatype_results:
-                        dt_loaded = load_entity_by_gid(dt.gid)
-                        if dt_loaded:
-                            result['results'].append(dt_loaded)
-                        else:
-                            self.logger.warning("Could not retrieve datatype %s" % str(dt))
-
+                    result['results'] = dao.get_results_for_operation(result['id'])
                 else:
                     result['results'] = None
                 operations.append(result)
@@ -297,18 +300,17 @@ class ProjectService:
 
             self.logger.debug("Deleting project: id=" + str(project_id) + ' name=' + project2delete.name)
             project_datatypes = dao.get_datatypes_in_project(project_id)
+
+            # Delete datatypes one by one in the reversed order of their creation date
             project_datatypes.sort(key=lambda dt: dt.create_date, reverse=True)
+            links = []
             for one_data in project_datatypes:
-                self.remove_datatype(project_id, one_data.gid, True)
+                new_links = self.remove_datatype(project_id, one_data.gid, True, links)
+                if new_links is not None:
+                    # Keep track of links so we don't create the same link more than once
+                    links.extend(new_links)
 
-            links = dao.get_links_for_project(project_id)
-            for one_link in links:
-                dao.remove_entity(Links, one_link.id)
-            project_bursts = dao.get_bursts_for_project(project_id)
-            for burst in project_bursts:
-                dao.remove_entity(burst.__class__, burst.id)
-
-            self.structure_helper.remove_project_structure(project2delete.name)
+            self.storage_interface.remove_project(project2delete)
             dao.delete_project(project_id)
             self.logger.debug("Deleted project: id=" + str(project_id) + ' name=' + project2delete.name)
 
@@ -462,10 +464,7 @@ class ProjectService:
             data = {}
             is_group = False
             group_op = None
-            dt_entity = dao.get_datatype_by_gid(dt.gid)
-            if dt_entity is None:
-                self.logger.warning("Ignored entity (possibly removed DT class)" + str(dt))
-                continue
+
             #  Filter by dt.type, otherwise Links to individual DT inside a group will be mistaken
             if dt.type == "DataTypeGroup" and dt.parent_operation.operation_group is not None:
                 is_group = True
@@ -477,7 +476,7 @@ class ProjectService:
             data[DataTypeMetaData.KEY_NODE_TYPE] = dt.display_type
             data[DataTypeMetaData.KEY_STATE] = dt.state
             data[DataTypeMetaData.KEY_SUBJECT] = str(dt.subject)
-            data[DataTypeMetaData.KEY_TITLE] = dt_entity.display_name
+            data[DataTypeMetaData.KEY_TITLE] = dt.display_name
             data[DataTypeMetaData.KEY_RELEVANCY] = dt.visible
             data[DataTypeMetaData.KEY_LINK] = dt.parent_operation.fk_launched_in != project.id
 
@@ -526,7 +525,28 @@ class ProjectService:
             # We ignore exception here (it was logged above, and we want to return no details).
             return meta_atts, states, None
 
-    def _remove_project_node_files(self, project_id, gid, skip_validation=False):
+    @staticmethod
+    def _add_links_for_datatype_references(datatype, fk_to_project, link_to_delete, existing_dt_links):
+        # If we found a datatype that has links, we need to link those as well to the linked project
+        # so they can be also copied
+
+        linked_datatype_paths = []
+        h5_file = h5.h5_file_for_index(datatype)
+        h5.gather_all_references_by_index(h5_file, linked_datatype_paths)
+
+        for h5_path in linked_datatype_paths:
+            if existing_dt_links is not None and h5_path in existing_dt_links:
+                continue
+
+            gid = H5File.get_metadata_param(h5_path, 'gid')
+            dt_index = h5.load_entity_by_gid(uuid.UUID(gid))
+            new_link = Links(dt_index.id, fk_to_project)
+            dao.store_entity(new_link)
+
+        dao.remove_entity(Links, link_to_delete)
+        return linked_datatype_paths
+
+    def _remove_project_node_files(self, project_id, gid, links, skip_validation=False):
         """
         Delegate removal of a node in the structure of the project.
         In case of a problem will THROW StructureException.
@@ -534,52 +554,43 @@ class ProjectService:
         try:
             project = self.find_project(project_id)
             datatype = dao.get_datatype_by_gid(gid)
-            links = dao.get_links_for_datatype(datatype.id)
 
-            op = dao.get_operation_by_id(datatype.fk_from_operation)
-            adapter = ABCAdapter.build_adapter(op.algorithm)
             if links:
-                was_link = False
-                for link in links:
-                    # This means it's only a link and we need to remove it
-                    if link.fk_from_datatype == datatype.id and link.fk_to_project == project.id:
-                        dao.remove_entity(Links, link.id)
-                        was_link = True
-                if not was_link:
-                    # Create a clone of the operation
-                    # There is no view_model so the view_model_gid is None
+                op = dao.get_operation_by_id(datatype.fk_from_operation)
+                # Instead of deleting, we copy the datatype to the linked project
+                # We also clone the operation
+                new_operation = self.__copy_linked_datatype_before_delete(op, datatype, project,
+                                                                          links[0].fk_to_project)
 
-                    new_op = Operation(op.view_model_gid,
-                                       dao.get_system_user().id,
-                                       links[0].fk_to_project,
-                                       datatype.parent_operation.fk_from_algo,
-                                       datatype.parent_operation.status,
-                                       datatype.parent_operation.start_date,
-                                       datatype.parent_operation.completion_date,
-                                       datatype.parent_operation.fk_operation_group,
-                                       datatype.parent_operation.additional_info,
-                                       datatype.parent_operation.user_group,
-                                       datatype.parent_operation.range_values)
-                    new_op = dao.store_entity(new_op)
-                    to_project = self.find_project(links[0].fk_to_project).name
+                # If there is a  datatype group and operation group and they were not moved yet to the linked project,
+                # then do it
+                if datatype.fk_datatype_group is not None:
+                    dt_group_op = dao.get_operation_by_id(datatype.fk_from_operation)
+                    op_group = dao.get_operationgroup_by_id(dt_group_op.fk_operation_group)
+                    op_group.fk_launched_in = links[0].fk_to_project
+                    dao.store_entity(op_group)
 
-                    full_path = h5.path_for_stored_index(datatype)
-                    self.structure_helper.move_datatype(datatype, to_project, str(new_op.id), full_path)
-                    # Move also the ViewModel H5
-                    old_folder = self.structure_helper.get_project_folder(project, str(op.id))
-                    view_model = adapter.load_view_model(op)
-                    vm_full_path = h5.determine_filepath(op.view_model_gid, old_folder)
-                    self.structure_helper.move_datatype(view_model, to_project, str(new_op.id), vm_full_path)
+                    burst = dao.get_burst_for_operation_id(op.id)
+                    if burst is not None:
+                        burst.fk_project = links[0].fk_to_project
+                        dao.store_entity(burst)
+
+                    dt_group = dao.get_datatypegroup_by_op_group_id(op_group.id)
+                    dt_group.parent_operation = new_operation
+                    dt_group.fk_from_operation = new_operation.id
+                    dao.store_entity(dt_group)
 
-                    datatype.fk_from_operation = new_op.id
-                    datatype.parent_operation = new_op
-                    dao.store_entity(datatype)
-                    dao.remove_entity(Links, links[0].id)
             else:
+                # There is no link for this datatype so it has to be deleted
                 specific_remover = get_remover(datatype.type)(datatype)
                 specific_remover.remove_datatype(skip_validation)
-                h5_path = h5.path_for_stored_index(datatype)
-                self.structure_helper.remove_datatype_file(h5_path)
+
+                # Remove burst if dt has one and it still exists
+                if datatype.fk_parent_burst is not None and datatype.is_ts:
+                    burst = dao.get_burst_for_operation_id(datatype.fk_from_operation)
+
+                    if burst is not None:
+                        dao.remove_entity(BurstConfiguration, burst.id)
 
         except RemoveDataTypeException:
             self.logger.exception("Could not execute operation Node Remove!")
@@ -588,6 +599,49 @@ class ProjectService:
             self.logger.exception("Remove operation failed")
             raise StructureException("Remove operation failed for unknown reasons.Please contact system administrator.")
 
+    def __copy_linked_datatype_before_delete(self, op, datatype, project, fk_to_project):
+        new_op = Operation(op.view_model_gid,
+                           dao.get_system_user().id,
+                           fk_to_project,
+                           datatype.parent_operation.fk_from_algo,
+                           datatype.parent_operation.status,
+                           datatype.parent_operation.start_date,
+                           datatype.parent_operation.completion_date,
+                           datatype.parent_operation.fk_operation_group,
+                           datatype.parent_operation.additional_info,
+                           datatype.parent_operation.user_group,
+                           datatype.parent_operation.range_values)
+        new_op.visible = datatype.parent_operation.visible
+        new_op = dao.store_entity(new_op)
+        to_project = self.find_project(fk_to_project)
+        to_project_path = self.storage_interface.get_project_folder(to_project.name)
+
+        full_path = h5.path_for_stored_index(datatype)
+        old_folder = self.storage_interface.get_project_folder(project.name, str(op.id))
+        file_paths = h5.gather_references_of_view_model(op.view_model_gid, old_folder, only_view_models=True)[0]
+        file_paths.append(full_path)
+
+        # The BurstConfiguration h5 file has to be moved only when we handle the time series which has the operation
+        # folder containing the file
+        if datatype.is_ts and datatype.fk_parent_burst is not None:
+            bc_path = h5.path_for(datatype.parent_operation.id, BurstConfigurationH5, datatype.fk_parent_burst,
+                                  project.name)
+            if os.path.exists(bc_path):
+                file_paths.append(bc_path)
+
+                bc = dao.get_burst_for_operation_id(op.id)
+                bc.fk_simulation = new_op.id
+                dao.store_entity(bc)
+
+        # Move all files to the new operation folder
+        self.storage_interface.move_datatype_with_sync(to_project, to_project_path, new_op.id, file_paths)
+
+        datatype.fk_from_operation = new_op.id
+        datatype.parent_operation = new_op
+        dao.store_entity(datatype)
+
+        return new_op
+
     def remove_operation(self, operation_id):
         """
         Remove a given operation
@@ -601,13 +655,13 @@ class ProjectService:
             # Here the Operation is mot probably already removed - in case DTs were found inside
             # but we still remove it for the case when no DTs exist
             dao.remove_entity(Operation, operation.id)
-            self.structure_helper.remove_operation_data(operation.project.name, operation_id)
-
+            self.storage_interface.remove_operation_data(operation.project.name, operation_id)
+            self.storage_interface.push_folder_to_sync(operation.project.name)
             self.logger.debug("Finished deleting operation %s " % operation)
         else:
             self.logger.warning("Attempt to delete operation with id=%s which no longer exists." % operation_id)
 
-    def remove_datatype(self, project_id, datatype_gid, skip_validation=False):
+    def remove_datatype(self, project_id, datatype_gid, skip_validation=False, existing_dt_links=None):
         """
         Method used for removing a dataType. If the given dataType is a DatatypeGroup
         or a dataType from a DataTypeGroup than this method will remove the entire group.
@@ -618,14 +672,25 @@ class ProjectService:
             self.logger.warning("Attempt to delete DT[%s] which no longer exists." % datatype_gid)
             return
 
+        if datatype.parent_operation.fk_launched_in != int(project_id):
+            self.logger.warning("Datatype with GUID [%s] has been moved to another project and does "
+                                "not need to be deleted anymore." % datatype_gid)
+            return
+
         is_datatype_group = False
         datatype_group = None
+        new_dt_links = []
+
+        # Datatype Groups were already handled when the first DatatypeMeasureIndex has been found
         if dao.is_datatype_group(datatype_gid):
             is_datatype_group = True
             datatype_group = datatype
+        # Found the first DatatypeMeasureIndex from a group
         elif datatype.fk_datatype_group is not None:
             is_datatype_group = True
-            datatype_group = dao.get_datatype_by_id(datatype.fk_datatype_group)
+            # We load it this way to make sure we have the 'fk_operation_group' in every case
+            datatype_group_gid = dao.get_datatype_by_id(datatype.fk_datatype_group).gid
+            datatype_group = h5.load_entity_by_gid(datatype_group_gid)
 
         operations_set = [datatype.fk_from_operation]
         correct = True
@@ -633,26 +698,50 @@ class ProjectService:
         if is_datatype_group:
             operations_set = [datatype_group.fk_from_operation]
             self.logger.debug("Removing datatype group %s" % datatype_group)
-            if datatype_group.fk_parent_burst:
-                burst = dao.get_generic_entity(BurstConfiguration, datatype_group.fk_parent_burst, 'gid')[0]
-                dao.remove_entity(BurstConfiguration, burst.id)
-                if burst.fk_metric_operation_group:
-                    correct = correct and self._remove_operation_group(burst.fk_metric_operation_group, project_id,
-                                                                       skip_validation, operations_set)
 
-                if burst.fk_operation_group:
-                    correct = correct and self._remove_operation_group(burst.fk_operation_group, project_id,
-                                                                       skip_validation, operations_set)
+            datatypes = self.get_all_datatypes_from_data(datatype_group)
+            first_datatype = datatypes[0]
 
+            if hasattr(first_datatype, 'fk_source_gid'):
+                ts = h5.load_entity_by_gid(first_datatype.fk_source_gid)
+                ts_group = dao.get_datatypegroup_by_op_group_id(ts.parent_operation.fk_operation_group)
+                dm_group = datatype_group
             else:
-                self._remove_datatype_group_dts(project_id, datatype_group.id, skip_validation, operations_set)
+                dt_measure_index = get_class_by_name("{}.{}".format(DATATYPE_MEASURE_INDEX_MODULE,
+                                                                    DATATYPE_MEASURE_INDEX_CLASS))
+                dm_group = dao.get_datatype_measure_group_from_ts_from_pse(first_datatype.gid, dt_measure_index)
+                ts_group = datatype_group
+
+            links = []
+
+            if ts_group:
+                links.extend(dao.get_links_for_datatype(ts_group.id))
+                correct = correct and self._remove_operation_group(ts_group.fk_operation_group, project_id,
+                                                                   skip_validation, operations_set, links)
+
+            if dm_group:
+                links.extend(dao.get_links_for_datatype(dm_group.id))
+                correct = correct and self._remove_operation_group(dm_group.fk_operation_group, project_id,
+                                                                   skip_validation, operations_set, links)
+
+            if len(links) > 0:
+                # We want to get the links for the first TSIndex directly
+                # This code works for all cases
+                datatypes = dao.get_datatype_in_group(ts_group.id)
+                ts = datatypes[0]
+
+                new_dt_links = self._add_links_for_datatype_references(ts, links[0].fk_to_project, links[0].id,
+                                                                       existing_dt_links)
 
-                datatype_group = dao.get_datatype_group_by_gid(datatype_group.gid)
-                dao.remove_entity(DataTypeGroup, datatype.id)
-                correct = correct and dao.remove_entity(OperationGroup, datatype_group.fk_operation_group)
         else:
             self.logger.debug("Removing datatype %s" % datatype)
-            self._remove_project_node_files(project_id, datatype.gid, skip_validation)
+            links = dao.get_links_for_datatype(datatype.id)
+
+            if len(links) > 0:
+                new_dt_links = self._add_links_for_datatype_references(datatype, links[0].fk_to_project, links[0].id,
+                                                                       existing_dt_links)
+
+            self._remove_project_node_files(project_id, datatype.gid, links, skip_validation)
 
         # Remove Operation entity in case no other DataType needs them.
         project = dao.get_project_by_id(project_id)
@@ -661,30 +750,35 @@ class ProjectService:
             if len(dependent_dt) > 0:
                 # Do not remove Operation in case DataType still exist referring it.
                 continue
-            op_burst = dao.get_burst_for_operation_id(operation_id)
-            if op_burst:
-                correct = correct and dao.remove_entity(BurstConfiguration, op_burst.id)
             correct = correct and dao.remove_entity(Operation, operation_id)
             # Make sure Operation folder is removed
-            self.structure_helper.remove_operation_data(project.name, operation_id)
+            self.storage_interface.remove_operation_data(project.name, operation_id)
 
+        self.storage_interface.push_folder_to_sync(project.name)
         if not correct:
             raise RemoveDataTypeException("Could not remove DataType " + str(datatype_gid))
+        return new_dt_links
 
-    def _remove_operation_group(self, operation_group_id, project_id, skip_validation, operations_set):
+    def _remove_operation_group(self, operation_group_id, project_id, skip_validation, operations_set, links):
         metrics_groups = dao.get_generic_entity(DataTypeGroup, operation_group_id,
                                                 'fk_operation_group')
         if len(metrics_groups) > 0:
             metric_datatype_group_id = metrics_groups[0].id
             self._remove_datatype_group_dts(project_id, metric_datatype_group_id, skip_validation,
-                                            operations_set)
-            dao.remove_entity(DataTypeGroup, metric_datatype_group_id)
-        return dao.remove_entity(OperationGroup, operation_group_id)
+                                            operations_set, links)
+            datatypes = dao.get_datatype_in_group(metric_datatype_group_id)
 
-    def _remove_datatype_group_dts(self, project_id, dt_group_id, skip_validation, operations_set):
+            # If this condition is false, then there is a link for the datatype group and we don't need to delete it
+            if len(datatypes) == 0:
+                dao.remove_entity(DataTypeGroup, metric_datatype_group_id)
+                return dao.remove_entity(OperationGroup, operation_group_id)
+            else:
+                return True
+
+    def _remove_datatype_group_dts(self, project_id, dt_group_id, skip_validation, operations_set, links):
         data_list = dao.get_datatypes_from_datatype_group(dt_group_id)
         for adata in data_list:
-            self._remove_project_node_files(project_id, adata.gid, skip_validation)
+            self._remove_project_node_files(project_id, adata.gid, links, skip_validation)
             if adata.fk_from_operation not in operations_set:
                 operations_set.append(adata.fk_from_operation)
 
@@ -750,7 +844,7 @@ class ProjectService:
             operation = dao.get_operation_by_id(datatype.fk_from_operation)
             operation.user_group = new_group_name
             dao.store_entity(operation)
-            op_folder = self.structure_helper.get_project_folder(operation.project, str(operation.id))
+            op_folder = self.storage_interface.get_project_folder(operation.project.name, str(operation.id))
             vm_gid = operation.view_model_gid
             view_model_file = h5.determine_filepath(vm_gid, op_folder)
             if view_model_file:
@@ -788,34 +882,6 @@ class ProjectService:
         datatype.fill_from_generic_attributes(ga)
         dao.store_entity(datatype)
 
-    def get_datatype_and_datatypegroup_inputs_for_operation(self, operation_gid, selected_filter):
-        """
-        Returns the dataTypes that are used as input parameters for the given operation.
-        'selected_filter' - is expected to be a visibility filter.
-
-        If any dataType is part of a dataType group then the dataType group will
-        be returned instead of that dataType.
-        """
-        all_datatypes = self._review_operation_inputs(operation_gid)[0]
-        datatype_inputs = []
-        for datatype in all_datatypes:
-            if selected_filter.display_name == StaticFiltersFactory.RELEVANT_VIEW:
-                if datatype.visible:
-                    datatype_inputs.append(datatype)
-            else:
-                datatype_inputs.append(datatype)
-        datatypes = []
-        datatype_groups = dict()
-        for data_type in datatype_inputs:
-            if data_type.fk_datatype_group is None:
-                datatypes.append(data_type)
-            elif data_type.fk_datatype_group not in datatype_groups:
-                dt_group = dao.get_datatype_by_id(data_type.fk_datatype_group)
-                datatype_groups[data_type.fk_datatype_group] = dt_group
-
-        datatypes.extend([v for v in datatype_groups.values()])
-        return datatypes
-
     def _review_operation_inputs(self, operation_gid):
         """
         :returns: A list of DataTypes that are used as input parameters for the specified operation.
@@ -901,3 +967,39 @@ class ProjectService:
     def is_datatype_group(datatype_gid):
         """ Used to check if the dataType with the specified GID is a DataTypeGroup. """
         return dao.is_datatype_group(datatype_gid)
+
+    def get_linked_datatypes_storage_path(self, project):
+        """
+        :return: the file paths to the datatypes that are linked in `project`
+        """
+        paths = []
+        for lnk_dt in dao.get_linked_datatypes_in_project(project.id):
+            # get datatype as a mapped type
+            path = h5.path_for_stored_index(lnk_dt)
+            if path is not None:
+                paths.append(path)
+            else:
+                self.logger.warning("Problem when trying to retrieve path on %s:%s!" % (lnk_dt.type, lnk_dt.gid))
+        return paths
+
+    @staticmethod
+    def get_all_datatypes_from_data(data):
+        """
+        This method builds an array with all data types to be processed later.
+        - If current data is a simple data type is added to an array.
+        - If it is an data type group all its children are loaded and added to array.
+        """
+        # first check if current data is a DataTypeGroup
+        if DataTypeGroup.is_data_a_group(data):
+            data_types = ProjectService.get_datatypes_from_datatype_group(data.id)
+
+            result = []
+            if data_types is not None and len(data_types) > 0:
+                for data_type in data_types:
+                    entity = load_entity_by_gid(data_type.gid)
+                    result.append(entity)
+
+            return result
+
+        else:
+            return [data]
