@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -47,7 +47,6 @@ from tvb.core.adapters import constants
 from tvb.core.adapters.abcadapter import ABCAdapter
 from tvb.core.adapters.abcdisplayer import ABCDisplayer
 from tvb.core.adapters.exceptions import LaunchException
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.filters.chain import FilterChain
 from tvb.core.entities.load import load_entity_by_gid
 from tvb.core.neocom import h5
@@ -57,7 +56,9 @@ from tvb.core.neotraits.view_model import DataTypeGidAttr
 from tvb.core.services.exceptions import OperationException
 from tvb.core.services.operation_service import OperationService, RANGE_PARAMETER_1, RANGE_PARAMETER_2
 from tvb.core.services.project_service import ProjectService
-from tvb.core.utils import url2path, string2bool
+from tvb.core.utils import url2path
+from tvb.storage.storage_interface import StorageInterface
+from tvb.storage.h5.utils import string2bool
 from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
@@ -89,7 +90,6 @@ class FlowController(BaseController):
     def __init__(self):
         BaseController.__init__(self)
         self.context = SelectedAdapterContext()
-        self.files_helper = FilesHelper()
         self.operation_services = OperationService()
         self.simulator_controller = SimulatorController()
 
@@ -398,8 +398,8 @@ class FlowController(BaseController):
         algorithm = self.algorithm_service.get_algorithm_by_identifier(algo_id)
         adapter_instance = ABCAdapter.build_adapter(algorithm)
         entity = load_entity_by_gid(entity_gid)
-        storage_path = self.files_helper.get_project_folder(entity.parent_operation.project,
-                                                            str(entity.fk_from_operation))
+        storage_path = StorageInterface().get_project_folder(entity.parent_operation.project.name,
+                                                             str(entity.fk_from_operation))
         adapter_instance.storage_path = storage_path
         method = getattr(adapter_instance, method_name)
         if kwargs:
