@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -33,46 +33,48 @@
 .. moduleauthor:: Ionel Ortelecan <ionel.ortelecan@codemart.ro>
 """
 
-import cherrypy
 import json
+import cherrypy
+
 from tvb.adapters.simulator.equation_forms import get_form_for_equation
 from tvb.adapters.simulator.model_forms import get_model_to_form_dict
-from tvb.adapters.simulator.subform_helper import SubformHelper
-from tvb.adapters.simulator.subforms_mapping import get_ui_name_to_equation_dict, GAUSSIAN_EQUATION, SIGMOID_EQUATION
-from tvb.basic.neotraits.api import Attr, Float
+from tvb.basic.neotraits.api import Attr, Float, EnumAttr, TupleEnum, TVBEnum
 from tvb.core.adapters.abcadapter import ABCAdapterForm
-from tvb.core.entities.storage import dao
-from tvb.core.neotraits.forms import Form, FormField, SelectField, FloatField
+from tvb.core.entities import load
+from tvb.core.neotraits.forms import Form, FormField, SelectField, FloatField, DynamicSelectField
 from tvb.core.neotraits.view_model import Str
 from tvb.core.services.burst_config_serialization import SerializationManager
-from tvb.datatypes.equations import Gaussian, SpatialApplicableEquation
+from tvb.datatypes.equations import Gaussian, Sigmoid
 from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.autologging import traced
 from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.decorators import expose_page, expose_fragment, handle_error, check_user, \
     using_template
-from tvb.interfaces.web.controllers.simulator_controller import SimulatorWizzardURLs
+from tvb.interfaces.web.controllers.simulator.simulator_controller import SimulatorWizzardURLs
 from tvb.interfaces.web.controllers.spatial.base_spatio_temporal_controller import SpatioTemporalController
 from tvb.interfaces.web.entities.context_model_parameters import SurfaceContextModelParameters
+from tvb.interfaces.web.entities.context_simulator import SimulatorContext
 
 ### SESSION KEY for ContextModelParameter entity.
 KEY_CONTEXT_MPS = "ContextForModelParametersOnSurface"
 
 
+class SurfaceModelEquationsEnum(TupleEnum):
+    GAUSSIAN = (Gaussian, "Gaussian")
+    SIGMOID = (Sigmoid, "Sigmoid")
+
+
 class SurfaceModelParametersForm(ABCAdapterForm):
     NAME_EQATION_PARAMS_DIV = 'equation_params'
-    default_equation = Gaussian
-    ui_name_to_equation_dict = get_ui_name_to_equation_dict()
-    equation_choices = {GAUSSIAN_EQUATION: ui_name_to_equation_dict.get(GAUSSIAN_EQUATION),
-                        SIGMOID_EQUATION: ui_name_to_equation_dict.get(SIGMOID_EQUATION)}
+    default_equation = SurfaceModelEquationsEnum.GAUSSIAN
 
     def __init__(self, model_params):
         super(SurfaceModelParametersForm, self).__init__()
 
-        self.model_param = SelectField(Str(label='Model parameter'), choices=model_params, name='model_param')
-        self.equation = SelectField(Attr(SpatialApplicableEquation, label='Equation', default=self.default_equation),
-                                    choices=self.equation_choices, name='equation',
-                                    subform=get_form_for_equation(self.default_equation))
+        self.model_param = DynamicSelectField(Str(label='Model parameter'), choices=model_params, name='model_param')
+        self.equation = SelectField(EnumAttr(label='Equation', default=self.default_equation),
+                                    name='equation',
+                                    subform=get_form_for_equation(self.default_equation.value))
 
     @staticmethod
     def get_required_datatype():
@@ -121,11 +123,15 @@ class SurfaceModelParametersController(SpatioTemporalController):
     EQUATION_PARAMS_FIELD = 'set_equation_param'
     base_url = '/spatial/modelparameters/surface'
 
+    def __init__(self):
+        super(SurfaceModelParametersController, self).__init__()
+        self.simulator_context = SimulatorContext()
+
     def get_data_from_burst_configuration(self):
         """
         Returns the model and surface instances from the burst configuration.
         """
-        des = SerializationManager(common.get_from_session(common.KEY_SIMULATOR_CONFIG))
+        des = SerializationManager(self.simulator_context.simulator)
         ### Read from session current burst-configuration
         if des.conf is None:
             return None, None
@@ -143,16 +149,13 @@ class SurfaceModelParametersController(SpatioTemporalController):
         cortex = des.conf.surface
         return model, cortex
 
-    def _prepare_model_params_dict(self, model):
+    def _prepare_model_params_list(self, model):
         model_form = get_model_to_form_dict().get(type(model))
         model_params = model_form.get_params_configurable_in_phase_plane()
         if len(model_params) == 0:
             self.logger.warning("The list with configurable parameters for the current model is empty!")
-        model_params_dict = {}
 
-        for param in model_params:
-            model_params_dict.update({param: param})
-        return model_params_dict
+        return model_params
 
     def _fill_form_from_context(self, config_form, context):
         if context.current_model_param in context.applied_equations:
@@ -162,7 +165,7 @@ class SurfaceModelParametersController(SpatioTemporalController):
             config_form.equation.subform_field.form = get_form_for_equation(type(current_equation))()
             config_form.equation.subform_field.form.fill_from_trait(current_equation)
         else:
-            context.current_equation = SurfaceModelParametersForm.default_equation()
+            context.current_equation = SurfaceModelParametersForm.default_equation.instance
             config_form.equation.data = type(context.current_equation)
             config_form.equation.subform_field.form.fill_from_trait(context.current_equation)
 
@@ -173,7 +176,7 @@ class SurfaceModelParametersController(SpatioTemporalController):
         }
         template_specification.update({'applied_equations': context.get_configure_info()})
 
-        config_form = SurfaceModelParametersForm(self.model_params_dict)
+        config_form = SurfaceModelParametersForm(self.model_params_list)
         config_form.model_param.data = context.current_model_param
         self._fill_form_from_context(config_form, context)
         template_specification.update({'adapter_form': self.render_adapter_form(config_form)})
@@ -189,18 +192,18 @@ class SurfaceModelParametersController(SpatioTemporalController):
         """
         model, cortex = self.get_data_from_burst_configuration()
         surface_gid = cortex.surface_gid
-        surface_index = dao.get_datatype_by_gid(surface_gid.hex)
+        surface_index = load.load_entity_by_gid(surface_gid)
 
-        self.model_params_dict = self._prepare_model_params_dict(model)
+        self.model_params_list = self._prepare_model_params_list(model)
         context_model_parameters = SurfaceContextModelParameters(surface_index, model,
-                                                                 SurfaceModelParametersForm.default_equation(),
-                                                                 list(self.model_params_dict.values())[0])
+                                                                 SurfaceModelParametersForm.default_equation,
+                                                                 self.model_params_list[0])
         common.add2session(KEY_CONTEXT_MPS, context_model_parameters)
 
         template_specification = dict(title="Spatio temporal - Model parameters")
         template_specification.update(self.display_surface(surface_gid.hex, cortex.region_mapping_data))
 
-        dummy_form_for_initialization = SurfaceModelParametersForm(self.model_params_dict)
+        dummy_form_for_initialization = SurfaceModelParametersForm(self.model_params_list)
         self.plotted_equation_prefixes = {
             self.MODEL_PARAM_FIELD: dummy_form_for_initialization.model_param.name,
             self.EQUATION_FIELD: dummy_form_for_initialization.equation.name,
@@ -226,12 +229,12 @@ class SurfaceModelParametersController(SpatioTemporalController):
     @using_template("form_fields/form_field")
     @handle_error(redirect=False)
     @check_user
-    def refresh_subform(self, equation, mapping_key):
-        eq_class = get_ui_name_to_equation_dict().get(equation)
+    def refresh_subform(self, equation):
+        eq_class = TVBEnum.string_to_enum(list(SurfaceModelEquationsEnum), equation).value
         context = common.get_from_session(KEY_CONTEXT_MPS)
         context.current_equation = eq_class()
 
-        eq_params_form = SubformHelper.get_subform_for_field_value(equation, mapping_key)
+        eq_params_form = get_form_for_equation(eq_class)()
         return {'adapter_form': eq_params_form, 'equationsPrefixes': self.plotted_equation_prefixes}
 
     @cherrypy.expose
@@ -302,15 +305,15 @@ class SurfaceModelParametersController(SpatioTemporalController):
         """
         if submit_action == "submit_action":
             context_model_parameters = common.get_from_session(KEY_CONTEXT_MPS)
-            simulator = common.get_from_session(common.KEY_SIMULATOR_CONFIG)
+            simulator = self.simulator_context.simulator
 
-            for param_name in self.model_params_dict.values():
+            for param_name in self.model_params_list:
                 param_data = context_model_parameters.get_data_for_model_param(param_name)
                 if param_data is None:
                     continue
                 setattr(simulator.model, param_name, param_data)
             ### Update in session the last loaded URL for burst-page.
-            common.add2session(common.KEY_LAST_LOADED_FORM_URL, SimulatorWizzardURLs.SET_INTEGRATOR_URL)
+            self.simulator_context.add_last_loaded_form_url_to_session(SimulatorWizzardURLs.SET_INTEGRATOR_URL)
 
         ### Clean from session drawing context
         common.remove_from_session(KEY_CONTEXT_MPS)
