@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -49,9 +49,7 @@ from formencode import validators
 from tvb.basic.profile import TvbProfile
 from tvb.core.entities.file.files_update_manager import FilesUpdateManager
 from tvb.core.services.authorization import AuthorizationManager
-from tvb.core.entities.file.data_encryption_handler import encryption_handler
 from tvb.core.services.exceptions import UsernameException
-from tvb.core.services.project_service import ProjectService
 from tvb.core.services.texture_to_json import color_texture_to_list
 from tvb.core.services.user_service import KEY_AUTH_TOKEN, USERS_PAGE_SIZE
 from tvb.core.services.user_service import UserService, KEY_PASSWORD, KEY_EMAIL, KEY_USERNAME, KEY_COMMENT
@@ -61,6 +59,7 @@ from tvb.interfaces.web.controllers.base_controller import BaseController
 from tvb.interfaces.web.controllers.decorators import check_user, expose_json, check_admin
 from tvb.interfaces.web.controllers.decorators import handle_error, using_template, settings, jsonify
 from tvb.interfaces.web.entities.context_simulator import SimulatorContext
+from tvb.storage.storage_interface import StorageInterface
 
 KEY_SERVER_VERSION = "versionInfo"
 KEY_CURRENT_VERSION_FULL = "currentVersionLongText"
@@ -185,8 +184,9 @@ class UserController(BaseController):
         if user is not None:
             self.logger.debug("User " + user.username + " is just logging out!")
         current_project = common.get_current_project()
-        if current_project is not None and encryption_handler.encryption_enabled():
-            encryption_handler.set_project_inactive(current_project)
+        storage_interface = StorageInterface()
+        if current_project is not None and storage_interface.encryption_enabled():
+            storage_interface.set_project_inactive(current_project)
         SimulatorContext().clean_project_data_from_session()
         common.set_info_message("Thank you for using The Virtual Brain!")
 
