@@ -4,7 +4,7 @@
  * TheVirtualBrain-Scientific Package (for simulators). See content of the
  * documentation-folder for more details. See also http://www.thevirtualbrain.org
  *
- * (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+ * (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
  *
  * This program is free software: you can redistribute it and/or modify it under the
  * terms of the GNU General Public License as published by the Free Software Foundation,
@@ -126,11 +126,11 @@ function _postInitializeTree(treeSelector) {
 //                More GENERIC functions from here
 //-----------------------------------------------------------------------
 
-function createLink(dataId, projectId, isGroup) {
+function createLink(dataId, projectId) {
     doAjaxCall({
         async : false,
         type: 'GET',
-        url: "/project/createlink/" + dataId +"/" + projectId + "/" + isGroup,
+        url: "/project/createlink/" + dataId +"/" + projectId,
         success: function(r) {if(r) displayMessage(r,'warningMessage'); },
         error:   function(r) {if(r) displayMessage(r,'warningMessage'); }
     });
