@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -35,17 +35,18 @@
 """
 
 import os
-import shutil
 import sys
 from functools import wraps
 from types import FunctionType
-from tvb.config.init.model_manager import reset_database
+
 from tvb.config.init.initializer import initialize
+from tvb.config.init.model_manager import reset_database
 from tvb.core.neocom.h5 import REGISTRY
 from tvb.tests.framework.datatypes.dummy_datatype import DummyDataType
 from tvb.tests.framework.datatypes.dummy_datatype2_index import DummyDataType2Index
 from tvb.tests.framework.datatypes.dummy_datatype_h5 import DummyDataTypeH5
 from tvb.tests.framework.datatypes.dummy_datatype_index import DummyDataTypeIndex
+from tvb.tests.storage.storage_test import BaseStorageTestCase
 
 
 def init_test_env():
@@ -79,9 +80,8 @@ if "TEST_INITIALIZATION_DONE" not in globals():
     init_test_env()
     TEST_INITIALIZATION_DONE = True
 
-from tvb.adapters.exporters.export_manager import ExportManager
 from tvb.core.services.operation_service import OperationService
-from tvb.core.entities.file.files_helper import FilesHelper
+from tvb.storage.storage_interface import StorageInterface
 from tvb.core.entities.storage import dao
 from tvb.core.entities.storage.session_maker import SessionMaker
 from tvb.core.entities.model.model_project import *
@@ -96,8 +96,7 @@ class BaseTestCase(object):
     """
     This class should implement basic functionality which is common to all TVB tests.
     """
-    EXCLUDE_TABLES = ["ALGORITHMS", "ALGORITHM_CATEGORIES", "PORTLETS",
-                      "MAPPED_INTERNAL__CLASS", "MAPPED_MAPPED_TEST_CLASS"]
+    EXCLUDE_TABLES = ["ALGORITHMS", "ALGORITHM_CATEGORIES"]
 
     def assertEqual(self, expected, actual, message=""):
         assert expected == actual, message + " Expected %s but got %s." % (expected, actual)
@@ -154,22 +153,17 @@ class BaseTestCase(object):
                 # Ignore potential wrongly written operations by other unit-tests
                 pass
 
-    def delete_project_folders(self):
+    @staticmethod
+    def delete_project_folders():
         """
         This method deletes folders for all projects from TVB folder.
         This is done without any check on database. You might get projects in DB but no folder for them on disk.
         """
-        projects_folder = os.path.join(TvbProfile.current.TVB_STORAGE, FilesHelper.PROJECTS_FOLDER)
-        if os.path.exists(projects_folder):
-            for current_file in os.listdir(projects_folder):
-                full_path = os.path.join(TvbProfile.current.TVB_STORAGE, FilesHelper.PROJECTS_FOLDER, current_file)
-                if os.path.isdir(full_path):
-                    shutil.rmtree(full_path, ignore_errors=True)
+        BaseStorageTestCase.delete_projects_folders()
 
-        for folder in [os.path.join(TvbProfile.current.TVB_STORAGE, ExportManager.EXPORT_FOLDER_NAME),
-                       os.path.join(TvbProfile.current.TVB_STORAGE, FilesHelper.TEMP_FOLDER)]:
-            if os.path.exists(folder):
-                shutil.rmtree(folder)
+        for folder in [os.path.join(TvbProfile.current.TVB_STORAGE, StorageInterface.EXPORT_FOLDER_NAME),
+                       os.path.join(TvbProfile.current.TVB_STORAGE, StorageInterface.TEMP_FOLDER)]:
+            StorageInterface.remove_folder(folder, True)
             os.makedirs(folder)
 
     def count_all_entities(self, entity_type):
