@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -28,15 +28,17 @@
 #
 #
 import os
-
 import numpy
-from tvb.core.entities.file.files_helper import FilesHelper
+from tvb.adapters.datatypes.h5.projections_h5 import ProjectionMatrixH5
+from tvb.core.adapters.abcadapter import ABCAdapter
+
 from tvb.core.entities.file.simulator.view_model import SimulatorAdapterModel, EEGViewModel, HeunStochasticViewModel, \
     TemporalAverageViewModel
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 from tvb.core.neocom.h5 import load, store, load_from_dir, store_to_dir
 from tvb.datatypes.projections import ProjectionSurfaceEEG
+from tvb.storage.storage_interface import StorageInterface
 
 
 def test_store_load(tmpdir, connectivity_factory):
@@ -62,7 +64,7 @@ def test_store_simulator_view_model(connectivity_index_factory, operation_factor
     sim_view_model.connectivity = conn.gid
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
+    storage_path = StorageInterface().get_project_folder(op.project.name, str(op.id))
 
     h5.store_view_model(sim_view_model, storage_path)
 
@@ -80,7 +82,7 @@ def test_store_simulator_view_model_noise(connectivity_index_factory, operation_
     sim_view_model.integrator.noise.noise_seed = 45
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
+    storage_path = StorageInterface().get_project_folder(op.project.name, str(op.id))
 
     h5.store_view_model(sim_view_model, storage_path)
 
@@ -100,8 +102,8 @@ def test_store_simulator_view_model_eeg(connectivity_index_factory, surface_inde
     proj = ProjectionSurfaceEEG(sensors=sensors, sources=surface, projection_data=numpy.ones(3))
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
-    prj_db_db = h5.store_complete(proj, storage_path)
+
+    prj_db_db = h5.store_complete(proj, op.id, op.project.name)
     prj_db_db.fk_from_operation = op.id
     dao.store_entity(prj_db_db)
 
@@ -112,7 +114,7 @@ def test_store_simulator_view_model_eeg(connectivity_index_factory, surface_inde
     sim_view_model.monitors = [seeg_monitor]
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
+    storage_path = StorageInterface().get_project_folder(op.project.name, str(op.id))
 
     h5.store_view_model(sim_view_model, storage_path)
 
@@ -129,7 +131,7 @@ def test_gather_view_model_and_datatype_references(connectivity_index_factory, o
     sim_view_model.connectivity = conn.gid
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
+    storage_path = StorageInterface().get_project_folder(op.project.name, str(op.id))
     h5.store_view_model(sim_view_model, storage_path)
 
     only_vm_references, _ = h5.gather_references_of_view_model(sim_view_model.gid, storage_path, True)
@@ -149,8 +151,7 @@ def test_gather_view_model_and_datatype_references_multiple_monitors(connectivit
     proj = ProjectionSurfaceEEG(sensors=sensors, sources=surface, projection_data=numpy.ones(3))
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
-    prj_db = h5.store_complete(proj, storage_path)
+    prj_db = h5.store_complete(proj, op.id, op.project.name)
     prj_db.fk_from_operation = op.id
     dao.store_entity(prj_db)
 
@@ -162,7 +163,7 @@ def test_gather_view_model_and_datatype_references_multiple_monitors(connectivit
     sim_view_model.monitors = [TemporalAverageViewModel(), seeg_monitor]
 
     op = operation_factory()
-    storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
+    storage_path = StorageInterface().get_project_folder(op.project.name, str(op.id))
     h5.store_view_model(sim_view_model, storage_path)
 
     only_vm_references, _ = h5.gather_references_of_view_model(sim_view_model.gid, storage_path, True)
