@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -32,19 +32,17 @@
 .. moduleauthor:: Paula Popa <paula.popa@codemart.ro>
 """
 import os
-import shutil
+
 import numpy
 import pytest
-from tvb.adapters.simulator.hpc_simulator_adapter import HPCSimulatorAdapter
 from tvb.basic.config.settings import HPCSettings
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.file.simulator.view_model import EEGViewModel
 from tvb.core.entities.storage import dao
 from tvb.core.neocom import h5
 from tvb.core.operation_hpc_launcher import do_operation_launch
 from tvb.core.services.backend_clients.hpc_scheduler_client import HPCSchedulerClient
-from tvb.core.services.encryption_handler import EncryptionHandler
 from tvb.datatypes.projections import ProjectionSurfaceEEG
+from tvb.storage.storage_interface import StorageInterface
 from tvb.tests.framework.core.base_testcase import BaseTestCase
 from tvb.tests.framework.core.factory import TestFactory
 
@@ -61,8 +59,9 @@ def _request_passfile_dummy(simulator_gid, op_id, base_url, passfile_folder):
 class TestHPCSchedulerClient(BaseTestCase):
 
     def setup_method(self):
-        self.files_helper = FilesHelper()
-        self.encryption_handler = EncryptionHandler('123')
+        self.storage_interface = StorageInterface()
+        self.dir_gid = '123'
+        self.encryption_handler = self.storage_interface.get_encryption_handler(self.dir_gid)
         self.clean_database()
         self.test_user = TestFactory.create_user()
         self.test_project = TestFactory.create_project(self.test_user)
@@ -119,8 +118,9 @@ class TestHPCSchedulerClient(BaseTestCase):
 
     def _do_operation_launch(self, op, sim_gid, mocker, is_pse=False):
         # Prepare encrypted dir
-        self.encryption_handler = EncryptionHandler(sim_gid)
-        job_encrypted_inputs = HPCSchedulerClient()._prepare_input(op, sim_gid)
+        self.dir_gid = sim_gid
+        self.encryption_handler = StorageInterface.get_encryption_handler(self.dir_gid)
+        job_encrypted_inputs = HPCSchedulerClient()._prepare_input(op, self.dir_gid)
         self.encryption_handler.encrypt_inputs(job_encrypted_inputs)
         encrypted_dir = self.encryption_handler.get_encrypted_dir()
 
@@ -128,10 +128,10 @@ class TestHPCSchedulerClient(BaseTestCase):
         mocker.patch('tvb.core.operation_hpc_launcher._update_operation_status', _update_operation_status)
 
         # Call do_operation_launch similarly to CSCS env
-        plain_dir = self.files_helper.get_project_folder(self.test_project, 'plain')
-        do_operation_launch(sim_gid.hex, 1000, is_pse, '', op.id, plain_dir)
+        plain_dir = self.storage_interface.get_project_folder(self.test_project.name, 'plain')
+        do_operation_launch(self.dir_gid, 1000, is_pse, '', op.id, plain_dir)
         assert len(os.listdir(encrypted_dir)) == 7
-        output_path = os.path.join(encrypted_dir, HPCSimulatorAdapter.OUTPUT_FOLDER)
+        output_path = os.path.join(encrypted_dir, HPCSchedulerClient.OUTPUT_FOLDER)
         assert os.path.exists(output_path)
         expected_files = 2
         if is_pse:
@@ -166,8 +166,7 @@ class TestHPCSchedulerClient(BaseTestCase):
         proj = ProjectionSurfaceEEG(sensors=sensors, sources=surface, projection_data=numpy.ones(3))
 
         op = operation_factory()
-        storage_path = FilesHelper().get_project_folder(op.project, str(op.id))
-        prj_db_db = h5.store_complete(proj, storage_path)
+        prj_db_db = h5.store_complete(proj, op.id, op.project.name)
         prj_db_db.fk_from_operation = op.id
         dao.store_entity(prj_db_db)
 
@@ -207,10 +206,6 @@ class TestHPCSchedulerClient(BaseTestCase):
 
     def teardown_method(self):
         encrypted_dir = self.encryption_handler.get_encrypted_dir()
-        if os.path.isdir(encrypted_dir):
-            shutil.rmtree(encrypted_dir)
         passfile = self.encryption_handler.get_password_file()
-        if os.path.exists(passfile):
-            os.remove(passfile)
-        self.files_helper.remove_project_structure(self.test_project.name)
+        self.storage_interface.remove_files([encrypted_dir, passfile])
         self.clean_database()
