@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -33,20 +33,20 @@
 """
 
 import os
-import shutil
+
 import pytest
 import tvb_data
 from tvb.basic.profile import TvbProfile
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.entities.model import model_datatype, model_project, model_operation
 from tvb.core.entities.storage import dao
 from tvb.core.entities.transient.context_overlay import DataTypeOverlayDetails
 from tvb.core.entities.transient.structure_entities import DataTypeMetaData
 from tvb.core.neocom import h5
-from tvb.core.services.exceptions import ProjectServiceException
 from tvb.core.services.algorithm_service import AlgorithmService
+from tvb.core.services.exceptions import ProjectServiceException
 from tvb.core.services.project_service import ProjectService, PROJECTS_PAGE_SIZE
-from tvb.tests.framework.adapters.testadapter3 import TestAdapter3
+from tvb.storage.storage_interface import StorageInterface
+from tvb.tests.framework.adapters.dummy_adapter3 import DummyAdapter3
 from tvb.tests.framework.core.base_testcase import TransactionalTestCase
 from tvb.tests.framework.core.factory import TestFactory, ExtremeTestFactory
 
@@ -64,16 +64,13 @@ class TestProjectService(TransactionalTestCase):
         Reset the database before each test.
         """
         self.project_service = ProjectService()
-        self.structure_helper = FilesHelper()
+        self.storage_interface = StorageInterface()
         self.test_user = TestFactory.create_user()
 
     def transactional_teardown_method(self):
         """
-        Remove project folders and clean up database.
+        Remove project folders.
         """
-        created_projects = dao.get_projects_for_user(self.test_user.id)
-        for project in created_projects:
-            self.structure_helper.remove_project_structure(project.name)
         self.delete_project_folders()
 
     def test_create_project_happy_flow(self):
@@ -94,7 +91,8 @@ class TestProjectService(TransactionalTestCase):
         users_for_project = dao.get_members_of_project(project.id)
         for user in users_for_project:
             assert user.id in [user1.id, user2.id, self.test_user.id], "Users not stored properly."
-        assert os.path.exists(os.path.join(TvbProfile.current.TVB_STORAGE, FilesHelper.PROJECTS_FOLDER,
+        assert os.path.exists(os.path.join(TvbProfile.current.TVB_STORAGE,
+                                           StorageInterface.PROJECTS_FOLDER,
                                            "test_project")), "Folder for project was not created"
 
     def test_create_project_empty_name(self):
@@ -112,14 +110,14 @@ class TestProjectService(TransactionalTestCase):
         Standard flow for editing an existing project.
         """
         selected_project = TestFactory.create_project(self.test_user, 'test_proj')
-        proj_root = self.structure_helper.get_project_folder(selected_project)
+        proj_root = self.storage_interface.get_project_folder(selected_project.name)
         initial_projects = dao.get_projects_for_user(self.test_user.id)
         assert len(initial_projects) == 1, "Database initialization probably failed!"
 
         edited_data = dict(name="test_project", description="test_description", users=[])
         edited_project = self.project_service.store_project(self.test_user, False, selected_project.id, **edited_data)
         assert not os.path.exists(proj_root), "Previous folder not deleted"
-        proj_root = self.structure_helper.get_project_folder(edited_project)
+        proj_root = self.storage_interface.get_project_folder(edited_project.name)
         assert os.path.exists(proj_root), "New folder not created!"
         assert selected_project.name != edited_project.name, "Project was no changed!"
 
@@ -128,7 +126,7 @@ class TestProjectService(TransactionalTestCase):
         Trying to edit an un-existing project.
         """
         selected_project = TestFactory.create_project(self.test_user, 'test_proj')
-        self.structure_helper.get_project_folder(selected_project)
+        self.storage_interface.get_project_folder(selected_project.name)
         initial_projects = dao.get_projects_for_user(self.test_user.id)
         assert len(initial_projects) == 1, "Database initialization probably failed!"
         data = dict(name="test_project", description="test_description", users=[])
@@ -242,8 +240,8 @@ class TestProjectService(TransactionalTestCase):
 
         for folder in os.listdir(TvbProfile.current.TVB_STORAGE):
             full_path = os.path.join(TvbProfile.current.TVB_STORAGE, folder)
-            if os.path.isdir(full_path) and folder.startswith('Generated'):
-                shutil.rmtree(full_path)
+            if folder.startswith('Generated'):
+                self.storage_interface.remove_folder(full_path)
 
     def test_retrieve_projects_page2(self):
         """
@@ -295,8 +293,8 @@ class TestProjectService(TransactionalTestCase):
             assert 0 != project.disk_size
             assert '0.0 KiB' != project.disk_size_human
 
-            prj_folder = self.structure_helper.get_project_folder(project)
-            actual_disk_size = FilesHelper.compute_recursive_h5_disk_usage(prj_folder)
+            prj_folder = self.storage_interface.get_project_folder(project.name)
+            actual_disk_size = self.storage_interface.compute_recursive_h5_disk_usage(prj_folder)
 
             ratio = float(actual_disk_size) / project.disk_size
             msg = "Real disk usage: %s The one recorded in the db : %s" % (actual_disk_size, project.disk_size)
@@ -329,7 +327,7 @@ class TestProjectService(TransactionalTestCase):
         Standard flow for deleting a project.
         """
         inserted_project = TestFactory.create_project(self.test_user, 'test_proj')
-        project_root = self.structure_helper.get_project_folder(inserted_project)
+        project_root = self.storage_interface.get_project_folder(inserted_project.name)
         projects = dao.get_projects_for_user(self.test_user.id)
         assert len(projects) == 1, "Initializations failed!"
         assert os.path.exists(project_root), "Something failed at insert time!"
@@ -372,7 +370,7 @@ class TestProjectService(TransactionalTestCase):
         project_to_link = dao.store_entity(project_to_link)
         exact_data = dao.get_datatype_by_gid(gid)
         assert exact_data is not None, "Initialization problem!"
-        dao.store_entity(model_datatype.Links(exact_data.id, project_to_link.id))
+        link = dao.store_entity(model_datatype.Links(exact_data.id, project_to_link.id))
 
         vw_h5_path = h5.path_for_stored_index(exact_data)
         assert os.path.exists(vw_h5_path)
@@ -382,7 +380,7 @@ class TestProjectService(TransactionalTestCase):
                                                   TvbProfile.current.web.admin.SYSTEM_USER_NAME, None, None, True,
                                                   None))
 
-        self.project_service._remove_project_node_files(inserted_project.id, gid)
+        self.project_service._remove_project_node_files(inserted_project.id, gid, [link])
 
         assert not os.path.exists(vw_h5_path)
         exact_data = dao.get_datatype_by_gid(gid)
@@ -391,7 +389,7 @@ class TestProjectService(TransactionalTestCase):
         assert os.path.exists(vw_h5_path_new)
         assert vw_h5_path_new != vw_h5_path
 
-        self.project_service._remove_project_node_files(project_to_link.id, gid)
+        self.project_service._remove_project_node_files(project_to_link.id, gid, [])
         assert dao.get_datatype_by_gid(gid) is None
 
     def test_update_meta_data_simple(self):
@@ -415,8 +413,8 @@ class TestProjectService(TransactionalTestCase):
         """
         Test the new update metaData for a group of dataTypes.
         """
-        test_adapter_factory(adapter_class=TestAdapter3)
-        group = datatype_group_factory()
+        test_adapter_factory(adapter_class=DummyAdapter3)
+        group, _ = datatype_group_factory()
         op_group_id = group.fk_operation_group
 
         new_meta_data = {DataTypeOverlayDetails.DATA_SUBJECT: "new subject",
@@ -459,7 +457,7 @@ class TestProjectService(TransactionalTestCase):
         project1 = project_factory(user, name="TestPS1")
         project2 = project_factory(user, name="TestPS2")
 
-        dt_group = datatype_group_factory(project=project1)
+        dt_group, _ = datatype_group_factory(project=project1)
         dt_simple = dummy_datatype_index_factory(state="RAW_DATA", project=project1)
         # Create 3 DTs directly in Project 2
         dummy_datatype_index_factory(state="RAW_DATA", project=project2)
@@ -478,7 +476,8 @@ class TestProjectService(TransactionalTestCase):
         expected_links.append(dt_group.gid)
 
         # Actually create the links from Prj1 into Prj2
-        AlgorithmService().create_link(link_ids, project2.id)
+        for link_id in link_ids:
+            AlgorithmService().create_link(link_id, project2.id)
 
         # Retrieve the raw data used to compose the tree (for easy parsing)
         dts_in_tree = dao.get_data_in_project(project2.id)
