@@ -1,12 +1,12 @@
 # -*- coding: utf-8 -*-
 #
 #
-# TheVirtualBrain-Scientific Package. This package holds all simulators, and
-# analysers necessary to run brain-simulations. You can use it stand alone or
-# in conjunction with TheVirtualBrain-Framework Package. See content of the
+# TheVirtualBrain-Framework Package. This package holds all Data Management, and
+# Web-UI helpful to run brain-simulations. To use it, you also need do download
+# TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -31,8 +31,8 @@
 import os
 import pytest
 import tvb_data
+
 from tvb.adapters.datatypes.db.connectivity import ConnectivityIndex
-from tvb.core.entities.file.files_helper import FilesHelper
 from tvb.core.utils import no_matlab
 from tvb.interfaces.rest.commons.exceptions import InvalidIdentifierException
 from tvb.interfaces.rest.server.resources.datatype.datatype_resource import RetrieveDatatypeResource, \
@@ -91,6 +91,3 @@ class TestDatatypeResource(RestResourceTest):
         result = self.get_operations_resource.get(datatype_gid=datatypes_in_project[0].gid)
         assert type(result) is list
         assert len(result) > 3
-
-    def transactional_teardown_method(self):
-        FilesHelper().remove_project_structure(self.test_project.name)
