@@ -6,7 +6,7 @@
 # TheVirtualBrain-Scientific Package (for simulators). See content of the
 # documentation-folder for more details. See also http://www.thevirtualbrain.org
 #
-# (c) 2012-2020, Baycrest Centre for Geriatric Care ("Baycrest") and others
+# (c) 2012-2022, Baycrest Centre for Geriatric Care ("Baycrest") and others
 #
 # This program is free software: you can redistribute it and/or modify it under the
 # terms of the GNU General Public License as published by the Free Software Foundation,
@@ -33,19 +33,21 @@
 .. moduleauthor:: Bogdan Neacsa <bogdan.neacsa@codemart.ro>
 """
 
-import os
-import json
 import copy
-import shutil
-import pytest
-import cherrypy
+import json
+import os
+from pathlib import Path
 from time import sleep
-from tvb.tests.framework.interfaces.web.controllers.base_controller_test import BaseTransactionalControllerTest
-from tvb.basic.profile import TvbProfile
+
+import cherrypy
+import pytest
 from tvb.basic.config import stored
+from tvb.basic.profile import TvbProfile
 from tvb.core.utils import get_matlab_executable, hash_password
 from tvb.interfaces.web.controllers import common
 from tvb.interfaces.web.controllers.settings_controller import SettingsController
+from tvb.storage.storage_interface import StorageInterface
+from tvb.tests.framework.interfaces.web.controllers.base_controller_test import BaseTransactionalControllerTest
 
 
 class TestSettingsController(BaseTransactionalControllerTest):
@@ -54,13 +56,14 @@ class TestSettingsController(BaseTransactionalControllerTest):
     """
 
     was_reset = False
-    accepted_db_url = ('sqlite:///TestFolder' + os.path.sep + 'tvb-database.db'
+    storage = str(Path.home()) + os.path.sep + "TestFolder"
+    accepted_db_url = ('sqlite:///' + storage + os.path.sep + 'tvb-database.db'
                        if TvbProfile.current.db.SELECTED_DB == 'sqlite'
                        else TvbProfile.current.db.DB_URL)
 
-    VALID_SETTINGS = {'KEYCLOAK_CONFIGURATION': 'TestFolder' + os.path.sep + 'keycloak-config.json',
-                      'KEYCLOAK_WEB_CONFIGURATION': 'TestFolder' + os.path.sep + 'keycloak-web-config.json',
-                      'TVB_STORAGE': "TestFolder",
+    VALID_SETTINGS = {'KEYCLOAK_CONFIGURATION': storage + os.path.sep + 'keycloak-config.json',
+                      'KEYCLOAK_WEB_CONFIGURATION': storage + os.path.sep + 'keycloak-web-config.json',
+                      'TVB_STORAGE': storage,
                       'USR_DISK_SPACE': 1,
                       'MAXIMUM_NR_OF_THREADS': 6,
                       'MAXIMUM_NR_OF_VERTICES_ON_SURFACE': 142,
@@ -89,9 +92,7 @@ class TestSettingsController(BaseTransactionalControllerTest):
         """ Cleans the testing environment """
         self.cleanup()
         self.clean_database()
-
-        if os.path.exists(self.VALID_SETTINGS['TVB_STORAGE']):
-            shutil.rmtree(self.VALID_SETTINGS['TVB_STORAGE'])
+        StorageInterface.remove_folder(self.VALID_SETTINGS['TVB_STORAGE'], True)
 
     def test_with_invalid_admin_settings(self):
 
@@ -144,7 +145,7 @@ class TestSettingsController(BaseTransactionalControllerTest):
     def test_with_valid_settings(self):
         # Ensure we submit acceptable values, depending on the current profile (set-up after fixtures execution)
         submit_data = copy.copy(self.VALID_SETTINGS)
-        accepted_db_url = ('sqlite:///TestFolder' + os.path.sep + 'tvb-database.db'
+        accepted_db_url = ('sqlite:///' + self.storage + os.path.sep + 'tvb-database.db'
                            if TvbProfile.current.db.SELECTED_DB == 'sqlite'
                            else TvbProfile.current.db.DB_URL)
         submit_data['SELECTED_DB'] = TvbProfile.current.db.SELECTED_DB
@@ -158,7 +159,7 @@ class TestSettingsController(BaseTransactionalControllerTest):
         # wait until 'restart' is done
         sleep(1)
         assert self.was_reset
-        assert len(TvbProfile.current.manager.stored_settings) == 20
+        assert len(TvbProfile.current.manager.stored_settings) == 21
 
         assert submit_data['TVB_STORAGE'] == TvbProfile.current.TVB_STORAGE
         assert submit_data['USR_DISK_SPACE'] * 2 ** 10 == TvbProfile.current.MAX_DISK_SPACE
